"""
This file provides autocompletions for the ZOS-API and was automatically generated.
It should not be edited manually.
"""

from __future__ import annotations

__all__ = (
    "DateTimeType",
    "EncodingType",
    "IPreferencesFolders",
    "IPreferencesFolders",
    "IPreferencesGeneral",
    "IPreferencesGeneral",
    "LanguageType",
    "ShowLineAsType",
)

class DateTimeType:
    # None = 0
    Date = 1
    DateTime = 2

class EncodingType:
    ANSI = 0
    Unicode = 1

class IPreferencesFolders:
    def ChangeDataDirectory(self, newDirectory: str) -> None: ...
    @property
    def CoatingDirectory(self) -> str: ...
    @property
    def CreoDirectory(self) -> str: ...
    @property
    def CreoInstallDirectory(self) -> str: ...
    @property
    def DataDirectory(self) -> str: ...
    @property
    def GlassDirectory(self) -> str: ...
    @property
    def ImagesDirectory(self) -> str: ...
    @property
    def InventorDirectory(self) -> str: ...
    @property
    def LensDirectory(self) -> str: ...
    @property
    def MatlabDirectory(self) -> str: ...
    @property
    def ObjectsDirectory(self) -> str: ...
    @property
    def PopDirectory(self) -> str: ...
    @property
    def ProgramDirectory(self) -> str: ...
    @property
    def ScatterDirectory(self) -> str: ...
    @property
    def SolidWorksDirectory(self) -> str: ...
    @property
    def UndoDirectory(self) -> str: ...
    @property
    def ZplDirectory(self) -> str: ...
    @CoatingDirectory.setter
    def CoatingDirectory(self, value: str) -> None: ...
    @CreoDirectory.setter
    def CreoDirectory(self, value: str) -> None: ...
    @CreoInstallDirectory.setter
    def CreoInstallDirectory(self, value: str) -> None: ...
    @GlassDirectory.setter
    def GlassDirectory(self, value: str) -> None: ...
    @ImagesDirectory.setter
    def ImagesDirectory(self, value: str) -> None: ...
    @InventorDirectory.setter
    def InventorDirectory(self, value: str) -> None: ...
    @LensDirectory.setter
    def LensDirectory(self, value: str) -> None: ...
    @MatlabDirectory.setter
    def MatlabDirectory(self, value: str) -> None: ...
    @ObjectsDirectory.setter
    def ObjectsDirectory(self, value: str) -> None: ...
    @PopDirectory.setter
    def PopDirectory(self, value: str) -> None: ...
    @ScatterDirectory.setter
    def ScatterDirectory(self, value: str) -> None: ...
    @SolidWorksDirectory.setter
    def SolidWorksDirectory(self, value: str) -> None: ...
    @UndoDirectory.setter
    def UndoDirectory(self, value: str) -> None: ...
    @ZplDirectory.setter
    def ZplDirectory(self, value: str) -> None: ...

class IPreferencesGeneral:
    @property
    def DateTimeFormat(self) -> DateTimeType: ...
    @property
    def IncludeCalculatedDataInSession(self) -> bool: ...
    @property
    def IncludeToleranceDataInSession(self) -> bool: ...
    @property
    def Language(self) -> LanguageType: ...
    @property
    def TXTFileEncoding(self) -> EncodingType: ...
    @property
    def UpdateMostRecentlyUsedList(self) -> bool: ...
    @property
    def UserPreferences(self) -> str: ...
    @property
    def UseSessionFiles(self) -> bool: ...
    @property
    def ZMXFileEncoding(self) -> EncodingType: ...
    def GetIsGPUEnabled(self) -> bool: ...
    def GetUseACIS(self) -> bool: ...
    @DateTimeFormat.setter
    def DateTimeFormat(self, value: DateTimeType) -> None: ...
    @IncludeCalculatedDataInSession.setter
    def IncludeCalculatedDataInSession(self, value: bool) -> None: ...
    @IncludeToleranceDataInSession.setter
    def IncludeToleranceDataInSession(self, value: bool) -> None: ...
    @Language.setter
    def Language(self, value: LanguageType) -> None: ...
    @TXTFileEncoding.setter
    def TXTFileEncoding(self, value: EncodingType) -> None: ...
    @UpdateMostRecentlyUsedList.setter
    def UpdateMostRecentlyUsedList(self, value: bool) -> None: ...
    @UserPreferences.setter
    def UserPreferences(self, value: str) -> None: ...
    @UseSessionFiles.setter
    def UseSessionFiles(self, value: bool) -> None: ...
    @ZMXFileEncoding.setter
    def ZMXFileEncoding(self, value: EncodingType) -> None: ...
    def SetIsGPUEnabled(self, isEnabled: bool) -> bool: ...
    def SetUseACIS(self, use: bool) -> bool: ...

class LanguageType:
    Chinese = 0
    English = 1
    Japanese = 4

class ShowLineAsType:
    TextAbove = 0
    FileName = 1
    ConfigurationNumber = 2
