"""
This file provides autocompletions for the ZOS-API and was automatically generated.
It should not be edited manually.
"""

from enum import Enum

__all__ = ("SagittalAberrationComponent", "TangentialAberrationComponent")

class SagittalAberrationComponent(Enum):
    Aberration_X = 0
    Aberration_Y = 1

class TangentialAberrationComponent(Enum):
    Aberration_Y = 0
    Aberration_X = 1
