"""
This file provides autocompletions for the ZOS-API and was automatically generated.
It should not be edited manually.
"""

from enum import Enum

__all__ = "PathAnalysisSortType"

class PathAnalysisSortType(Enum):
    TotalEndingFlux = 0
    NumberOfObjectsStruck = 1
    NumberOfBranches = 2
    LastObjectStruck = 3
    NumberOfUniqueObjectsStruct = 4
