"""
This file provides autocompletions for the ZOS-API and was automatically generated.
It should not be edited manually.
"""

from enum import Enum

__all__ = ("ToleranceColumn", "ToleranceOperandType")

class ToleranceColumn(Enum):
    Param1 = 2
    Param2 = 3
    Param3 = 4
    Nominal = 5
    Min = 6
    Max = 7
    Comment = 8

class ToleranceOperandType(Enum):
    TOFF = 0
    TRAD = 1
    TCUR = 2
    TFRN = 3
    TTHI = 4
    TCON = 5
    TSDI = 6
    TSDX = 7
    TSDY = 8
    TSDR = 9
    TSTX = 10
    TSTY = 11
    TIRX = 12
    TIRY = 13
    TIRR = 14
    TPAR = 15
    TEDV = 16
    TEDX = 17
    TEDY = 18
    TEDR = 19
    TETX = 20
    TETY = 21
    TETZ = 22
    TUDX = 23
    TUDY = 24
    TUTX = 25
    TUTY = 26
    TUTZ = 27
    TIND = 28
    TABB = 29
    TEXI = 30
    SAVE = 31
    COMP = 32
    CPAR = 33
    CEDV = 34
    CMCO = 35
    STAT = 36
    TWAV = 37
    TNPS = 38
    TNPA = 39
    TMCO = 40
    TEZI = 41
    TCMU = 42
    SEED = 43
    COMM = 44
    TPAI = 45
    TCIO = 46
    TCEO = 47
    TNMA = 48
    CNPA = 49
    CNPS = 50
    TRLX = 51
    TRLY = 52
    TRLR = 53
    TARX = 54
    TARY = 55
    TARR = 56
